# hundun

hundun is a python library for the exploration of chaos.   

See [hundun.wiki](https://github.com/llbxg/hundun/wiki) for details.

## Gallery

### [`Drawing.trajectory_3d`](https://github.com/llbxg/hundun/wiki/Drawing#trajectory_3d-)
![image:trajectory_3d](https://raw.githubusercontent.com/wiki/llbxg/hundun/image/trajectory_3d.gif)


### [`est_lag_w_acf`](https://github.com/llbxg/hundun/wiki/Estimate-the-time-lag#est_lag_w_acf)
![image:est_lag_w_acf](https://raw.githubusercontent.com/wiki/llbxg/hundun/image/est_lag_w_acf.png)


### [`calc_dimension_capacity`](https://github.com/llbxg/hundun/wiki/Calculate-the-generalized-dimension#calc_dimension_capacity)
![image:calc_dimension_capacity](https://raw.githubusercontent.com/wiki/llbxg/hundun/image/dimension_capacity.png)


### [`show_recurrence_plot`](https://github.com/llbxg/hundun/wiki/Visualization#show_recurrence_plot)
![image:show_recurrence_plot](https://raw.githubusercontent.com/wiki/llbxg/hundun/image/show_recurrence_plot2.png)


### [`calc_les`](https://github.com/llbxg/hundun/wiki/Lyapunov-exponents#calc_les)
![image:calc_les](https://raw.githubusercontent.com/wiki/llbxg/hundun/image/calc_les-Henon.png)


### [`calc_les`](https://github.com/llbxg/hundun/wiki/Lyapunov-exponents#calc_les)
![image:calc_les](https://raw.githubusercontent.com/wiki/llbxg/hundun/image/calc_les-Lorenz.png)
